function createfigure1(X1, Y1, S1, C1, X2, Y2, C2, X3, Y3, C3, X4, Y4, C4, X5, X6, YMatrix1)
%CREATEFIGURE1(X1,Y1,S1,C1,X2,Y2,C2,X3,Y3,C3,X4,Y4,C4,X5,X6,YMATRIX1)
%  X1:  scatter x
%  Y1:  scatter y
%  S1:  scatter s
%  C1:  scatter c
%  X2:  scatter x
%  Y2:  scatter y
%  C2:  scatter c
%  X3:  scatter x
%  Y3:  scatter y
%  C3:  scatter c
%  X4:  scatter x
%  Y4:  scatter y
%  C4:  scatter c
%  X5:  vector of x data
%  X6:  vector of x data
%  YMATRIX1:  matrix of y data

%  Auto-generated by MATLAB on 13-Nov-2013 17:54:52

% Create figure
figure1 = figure('Tag','ProbabilisticMethodResults');

% Create axes
axes1 = axes('Parent',figure1,'Tag','axARS','YTick',zeros(1,0),...
    'XTick',zeros(1,0),...
    'Position',[0.13 0.409632352941177 0.775 0.515367647058823],...
    'PlotBoxAspectRatio',[12 12 1],...
    'DataAspectRatio',[1 1 1],...
    'Color','none');
% Uncomment the following line to preserve the X-limits of the axes
% xlim(axes1,[-6 6]);
% Uncomment the following line to preserve the Y-limits of the axes
% ylim(axes1,[-6 6]);
hold(axes1,'all');

% Create axes
axes2 = axes('Parent',figure1,'Tag','axSamples',...
    'Position',[0.13 0.409632352941177 0.775 0.515367647058823],...
    'PlotBoxAspectRatio',[6 6 1],...
    'DataAspectRatio',[1 1 1]);
% Uncomment the following line to preserve the X-limits of the axes
% xlim(axes2,[-6 6]);
% Uncomment the following line to preserve the Y-limits of the axes
% ylim(axes2,[-6 6]);
box(axes2,'on');
hold(axes2,'all');

% Create scatter
scatter(X1,Y1,S1,C1,'MarkerEdgeColor',[0 0 1],'Marker','+','Tag','P1',...
    'Parent',axes2,...
    'DisplayName','not converged (approximated)');

% Create scatter
scatter(X2,Y2,S1,C2,'MarkerEdgeColor',[0 1 1],'Tag','P2','Parent',axes2,...
    'DisplayName','approximated');

% Create scatter
scatter(X3,Y3,S1,C3,'MarkerEdgeColor',[0 1 0],'Tag','P3','Parent',axes2,...
    'DisplayName','exact');

% Create scatter
scatter(X4,Y4,S1,C4,'MarkerEdgeColor',[1 0 1],'Marker','+','Tag','P3',...
    'Parent',axes2,...
    'DisplayName','not converged (exact)');

% Create plot
plot(X5,X5,'Parent',axes2,'Marker','+','LineStyle','none',...
    'DisplayName','origin',...
    'Color',[0 0 0]);

% Create multiple lines using matrix input to plot
plot1 = plot(X6,YMatrix1,'Parent',axes2,'Color',[1 0 0]);
set(plot1(1),'Tag','B1','LineStyle',':','DisplayName','\beta_{min}');
set(plot1(2),'Tag','B2','DisplayName','\beta_{threshold}');

% Create xlabel
xlabel('u_1');

% Create ylabel
ylabel('u_2');

% uitable currently does not support code generation, enter 'doc uitable' for correct input syntax
% In order to generate code for uitable, you may use GUIDE. Enter 'doc guide' for more information

% uitable(...);

% Create legend
legend1 = legend(axes2,'show');
set(legend1,...
    'Position',[0.689873118190708 0.755804188895475 0.171698113207547 0.166666666666667]);

